@@ -105,8 +105,11 @@ void align_worker(size_t thread_id, const Parameters *params, const Metadata *me
 		if (*output_format != Output_format::null) {
 			buf = new TextBuffer;
 			const bool aligned = mapper->generate_output(*buf, stat, *metadata);
-			if (aligned && (!config.unaligned.empty() || !config.aligned_file.empty()))
+			if (aligned && (!config.unaligned.empty() || !config.aligned_file.empty())) {
+				query_aligned_mtx.lock();
 				query_aligned[hits.query] = true;
+				query_aligned_mtx.unlock();
+			}
 		}
 		delete mapper;
 		OutputSink::get().push(hits.query, buf);
@@ -134,14 +137,15 @@ void align_queries(Trace_pt_buffer &trace_pts, Consumer* output_file, const Para
 		timer.go("Computing alignments");
 		Align_fetcher::init(query_range.first, query_range.second, v->begin(), v->end());
 		OutputSink::instance = unique_ptr<OutputSink>(new OutputSink(query_range.first, output_file));
-		Thread_pool threads;
+		vector<thread> threads;
 		if (config.verbosity >= 3 && config.load_balancing == Config::query_parallel)
-			threads.push_back(launch_thread(heartbeat_worker, query_range.second));
+			threads.emplace_back(heartbeat_worker, query_range.second);
 		size_t n_threads = config.load_balancing == Config::query_parallel ? (config.threads_align == 0 ? config.threads_ : config.threads_align) : 1;
 		for (size_t i = 0; i < n_threads; ++i)
 			//threads.push_back(launch_thread(static_cast<void(*)(size_t)>(&align_worker), i));
-			threads.push_back(launch_thread(align_worker, i, &params, &metadata));
-		threads.join_all();
+			threads.emplace_back(align_worker, i, &params, &metadata);
+		for (auto &t : threads)
+			t.join();
 		timer.finish();
 
 		double t = timer.get();
