@@ -21,7 +21,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "config.h"
 #include "../util/util.h"
 #include "../util/log_stream.h"
-#include "../util/tinythread.h"
 #include "../basic/value.h"
 #include "score_matrix.h"
 #include "../util/system.h"
@@ -71,7 +70,9 @@ Config::Config(int argc, const char **argv)
 		.add_command("smith-waterman", "")
 		.add_command("protein-snps", "")
 		.add_command("cluster", "")
-		.add_command("translate", "");
+		.add_command("translate", "")
+		.add_command("filter-blasttab", "")
+		.add_command("show-cbs", "");
 
 	Options_group general("General options");
 	general.add()
@@ -116,7 +117,9 @@ Config::Config(int argc, const char **argv)
 \tsalltitles means All Subject Title(s), separated by a '<>'\n\
 \tqcovhsp means Query Coverage Per HSP\n\
 \tqtitle means Query title\n\
-\tqqual means Query quality values\n\
+\tqqual means Query quality values for the aligned part of the query\n\
+\tfull_qqual means Query quality values\n\
+\tqstrand means Query strand\n\
 \n\tDefault: qseqid sseqid pident length mismatch gapopen qstart qend sstart send evalue bitscore", output_format)
 ("verbose", 'v', "verbose console output", verbose)
 ("log", 0, "enable debug log", debug_log)
@@ -167,6 +170,7 @@ Config::Config(int argc, const char **argv)
 		("no-self-hits", 0, "suppress reporting of identical self hits", no_self_hits)
 		("taxonmap", 0, "protein accession to taxid mapping file", prot_accession2taxid)
 		("taxonnodes", 0, "taxonomy nodes.dmp from NCBI", nodesdmp)
+		("taxonnames", 0, "taxonomy names.dmp from NCBI", namesdmp)
 		("taxonlist", 0, "restrict search to list of taxon ids (comma-separated)", taxonlist);
 
 	Options_group advanced("Advanced options");
@@ -192,7 +196,8 @@ Config::Config(int argc, const char **argv)
 		("range-cover", 0, "percentage of query range to be covered for hit culling (default=50)", query_range_cover, 50.0)
 		("dbsize", 0, "effective database size (in letters)", db_size)
 		("no-auto-append", 0, "disable auto appending of DAA and DMND file extensions", no_auto_append)
-		("xml-blord-format", 0, "Use gnl|BL_ORD_ID| style format in XML output", xml_blord_format);
+		("xml-blord-format", 0, "Use gnl|BL_ORD_ID| style format in XML output", xml_blord_format)
+		("stop-match-score", 0, "Set the match score of stop codons against each other.", stop_match_score, 1);
 
 	Options_group view_options("View options");
 	view_options.add()
@@ -266,7 +271,13 @@ Config::Config(int argc, const char **argv)
 		("use-dataset-field", 0, "", use_dataset_field)
 		("store-query-quality", 0, "", store_query_quality)
 		("swipe-chunk-size", 0, "", swipe_chunk_size, 256u)
-		("query-parallel-limit", 0, "", query_parallel_limit, 1000000u);
+		("query-parallel-limit", 0, "", query_parallel_limit, 1000000u)
+		("hard-masked", 0, "", hardmasked)
+		("cbs-window", 0, "", cbs_window, 40)
+		("tantan-r", 0, "", tantan_r, 0.005)
+		("tantan-s", 0, "", tantan_s, 0.5)
+		("no-unlink", 0, "", no_unlink)
+		("no-dict", 0, "", no_dict);
 		
 	parser.add(general).add(makedb).add(aligner).add(advanced).add(view_options).add(getseq_options).add(hidden_options);
 	parser.store(argc, argv, command);
@@ -361,13 +372,15 @@ Config::Config(int argc, const char **argv)
 			auto_append_extension(output_file, ".gz");
 	}
 
-	message_stream << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << " | by Benjamin Buchfink <buchfink@gmail.com>" << endl;
-	message_stream << "Licensed under the GNU GPL <https://www.gnu.org/licenses/gpl.txt>" << endl;
-	message_stream << "Check http://github.com/bbuchfink/diamond for updates." << endl << endl;
+	ostream &header_out = command == Config::help ? cout : cerr;
+	header_out << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << " | by Benjamin Buchfink <buchfink@gmail.com>" << endl;
+	header_out << "Licensed under the GNU GPL <https://www.gnu.org/licenses/gpl.txt>" << endl;
+	header_out << "Check http://github.com/bbuchfink/diamond for updates." << endl << endl;
+	log_stream << Const::program_name << " v" << Const::version_string << "." << (unsigned)Const::build_version << endl;
 #ifndef NDEBUG
 	verbose_stream << "Assertions enabled." << endl;
 #endif
-	set_option(threads_, tthread::thread::hardware_concurrency());
+	set_option(threads_, std::thread::hardware_concurrency());
 
 	switch (command) {
 	case Config::makedb:
@@ -394,7 +407,7 @@ Config::Config(int argc, const char **argv)
 		if (query_range_culling && frame_shift == 0)
 			throw std::runtime_error("Query range culling is only supported in frameshift alignment mode (option -F).");
 		if (matrix_file == "")
-			score_matrix = Score_matrix(to_upper_case(matrix), gap_open, gap_extend, frame_shift);
+			score_matrix = Score_matrix(to_upper_case(matrix), gap_open, gap_extend, frame_shift, stop_match_score);
 		else {
 			if (lambda == 0 || K == 0)
 				throw std::runtime_error("Custom scoring matrices require setting the --lambda and --K options.");
