@@ -171,11 +171,19 @@ struct Config
 	bool output_header;
 	string alfmt;
 	string unfmt;
+	string namesdmp;
+	bool hardmasked;
+	int cbs_window;
+	double tantan_r;
+	double tantan_s;
+	bool no_unlink;
+	bool no_dict;
+	int stop_match_score;
 
 	enum {
 		makedb = 0, blastp = 1, blastx = 2, view = 3, help = 4, version = 5, getseq = 6, benchmark = 7, random_seqs = 8, compare = 9, sort = 10, roc = 11, db_stat = 12, model_sim = 13,
 		match_file_stat = 14, model_seqs = 15, opt = 16, mask = 17, fastq2fasta = 18, dbinfo = 19, test_extra = 20, test_io = 21, db_annot_stats = 22, read_sim = 23, info = 24, seed_stat = 25,
-		smith_waterman = 26, protein_snps = 27, cluster = 28, translate = 29
+		smith_waterman = 26, protein_snps = 27, cluster = 28, translate = 29, filter_blasttab = 30, show_cbs = 31
 	};
 	unsigned	command;
 
