@@ -46,20 +46,20 @@ void Masking::operator()(Letter *seq, size_t len) const
 {
 	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), 50,
 		(tantan::const_double_ptr*)probMatrixPointers_,
-		0.005, 0.05,
+		config.tantan_r, 0.05,
 		0.9,
 		0, 0,
-		0.5, (const tantan::uchar*)mask_table_x_);
+		config.tantan_s, (const tantan::uchar*)mask_table_x_);
 }
 
 void Masking::mask_bit(Letter *seq, size_t len) const
 {
 	tantan::maskSequences((tantan::uchar*)seq, (tantan::uchar*)(seq + len), 50,
 		(tantan::const_double_ptr*)probMatrixPointers_,
-		0.005, 0.05,
+		config.tantan_r, 0.05,
 		0.9,
 		0, 0,
-		0.5, (const tantan::uchar*)mask_table_bit_);
+		config.tantan_s, (const tantan::uchar*)mask_table_bit_);
 }
 
 void Masking::bit_to_hard_mask(Letter *seq, size_t len, size_t &n) const
@@ -90,9 +90,10 @@ void mask_worker(Atomic<size_t> *next, Sequence_set *seqs, const Masking *maskin
 
 void mask_seqs(Sequence_set &seqs, const Masking &masking, bool hard_mask)
 {
-	Thread_pool threads;
+	vector<thread> threads;
 	Atomic<size_t> next(0);
 	for (size_t i = 0; i < config.threads_; ++i)
-		threads.push_back(launch_thread(mask_worker, &next, &seqs, &masking, hard_mask));
-	threads.join_all();
+		threads.emplace_back(mask_worker, &next, &seqs, &masking, hard_mask);
+	for (auto &t : threads)
+		t.join();
 }
\ No newline at end of file
