@@ -33,6 +33,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "taxon_list.h"
 #include "taxonomy_nodes.h"
 #include "../util/algo/MurmurHash3.h"
+#include "../util/io/record_reader.h"
 
 String_set<0>* ref_ids::data_ = 0;
 Partitioned_histogram ref_hst;
@@ -47,17 +48,18 @@ Serializer& operator<<(Serializer &s, const ReferenceHeader2 &h)
 	s.unset(Serializer::VARINT);
 	s << sizeof(ReferenceHeader2);
 	s.write(h.hash, sizeof(h.hash));
-	s << h.taxon_array_offset << h.taxon_array_size << h.taxon_nodes_offset;
+	s << h.taxon_array_offset << h.taxon_array_size << h.taxon_nodes_offset << h.taxon_names_offset;
 	return s;
 }
 
 Deserializer& operator>>(Deserializer &d, ReferenceHeader2 &h)
 {
-	d.varint = false;
-	uint64_t size;
-	d >> size;
-	d.read(h.hash, sizeof(h.hash));
-	d >> h.taxon_array_offset >> h.taxon_array_size >> h.taxon_nodes_offset;
+	d.read_record().read(h.hash, sizeof(h.hash))
+		>> h.taxon_array_offset
+		>> h.taxon_array_size
+		>> h.taxon_nodes_offset
+		>> h.taxon_names_offset
+		>> Finish();
 	return d;
 }
 
@@ -78,8 +80,10 @@ void DatabaseFile::init()
 {
 	read_header(*this, ref_header);
 	*this >> header2;
-	if (ref_header.build < min_build_required || ref_header.db_version != ReferenceHeader::current_db_version)
-		throw std::runtime_error("Database was built with a different version of Diamond and is incompatible.");
+	if (ref_header.build < min_build_required || ref_header.db_version < MIN_DB_VERSION)
+		throw std::runtime_error("Database was built with an older version of Diamond and is incompatible.");
+	if (ref_header.db_version > ReferenceHeader::current_db_version)
+		throw std::runtime_error("Database was built with a newer version of Diamond and is incompatible.");
 	if (ref_header.sequences == 0)
 		throw std::runtime_error("Incomplete database file. Database building did not complete successfully.");
 	pos_array_offset = ref_header.pos_array_offset;
@@ -124,6 +128,10 @@ bool DatabaseFile::has_taxon_nodes()
 	return header2.taxon_nodes_offset != 0;
 }
 
+bool DatabaseFile::has_taxon_scientific_names() {
+	return header2.taxon_names_offset != 0;
+
+}
 
 void DatabaseFile::rewind()
 {
@@ -221,6 +229,10 @@ void make_db(TempFile **tmp_out)
 		header2.taxon_nodes_offset = out->tell();
 		TaxonomyNodes::build(*out);
 	}
+	if (!config.namesdmp.empty()) {
+		header2.taxon_names_offset = out->tell();
+		*out << taxonomy.name_;
+	}
 
 	timer.go("Closing the input file");
 	db_file->close();
@@ -374,6 +386,10 @@ void DatabaseFile::get_seq()
 				sequence(seq).print(buf, value_traits, sequence::Reversed());
 				buf << '\n';
 			}
+			else if (config.hardmasked) {
+				sequence(seq).print(buf, value_traits, sequence::Hardmasked());
+				buf << '\n';
+			}
 			else
 				buf << sequence(seq) << '\n';
 		}
