@@ -25,6 +25,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../basic/packed_loc.h"
 #include "../util/system.h"
 #include "../util/algo/hash_join.h"
+#include "../util/parallel/thread_pool.h"
 
 #pragma pack(1)
 
@@ -68,8 +69,7 @@ struct sorted_list
 		seqs.enum_seeds(cb, seq_partition, sh, sh + 1, filter);
 		if (config.hash_join) return;
 		timer.go("Sorting seed list");
-		Sort_context sort_context(*this);
-		launch_scheduled_thread_pool(sort_context, Const::seedp, config.threads_);
+		Util::Parallel::scheduled_thread_pool_auto(config.threads_, Const::seedp, sort_worker, this);
 	}
 	
 	template<typename _t>
@@ -105,8 +105,8 @@ struct sorted_list
 	typedef Iterator_base<entry> iterator;
 	typedef Iterator_base<const entry> const_iterator;
 
-	const_iterator get_partition_cbegin(unsigned p) const;
-	iterator get_partition_begin(unsigned p) const;
+	const_iterator get_partition_cbegin(size_t p) const;
+	iterator get_partition_begin(size_t p) const;
 
 	struct Random_access_iterator
 	{
@@ -140,8 +140,8 @@ struct sorted_list
 		return i.i - cptr_begin(p);
 	}
 	
-	entry* ptr_begin(unsigned i) const;
-	entry* ptr_end(unsigned i) const;
+	entry* ptr_begin(size_t i) const;
+	entry* ptr_end(size_t i) const;
 
 	Random_access_iterator random_access(unsigned p, size_t offset) const;
 
@@ -186,22 +186,14 @@ private:
 		uint8_t  n[Const::seedp];
 	};
 
-	const entry* cptr_begin(unsigned i) const;
-	const entry* cptr_end(unsigned i) const;
+	const entry* cptr_begin(size_t i) const;
+	const entry* cptr_end(size_t i) const;
 
 	Ptr_set build_iterators(const shape_histogram &hst) const;
 
-	struct Sort_context
-	{
-		Sort_context(sorted_list &sl):
-			sl (sl)
-		{ }
-		void operator()(unsigned thread_id, unsigned seedp) const
-		{
-			std::sort(sl.ptr_begin(seedp), sl.ptr_end(seedp));
-		}
-		sorted_list &sl;
-	};
+	static void sort_worker(size_t p, size_t thread_id, sorted_list *sl) {
+		std::sort(sl->ptr_begin(p), sl->ptr_end(p));
+	}
 
 	struct Limits : vector<size_t>
 	{
