@@ -18,16 +18,17 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdio.h>
 #include <set>
+#include <stdexcept>
 #include "taxonomy.h"
 #include "../util/io/text_input_file.h"
 #include "../basic/config.h"
 #include "../util/merge_sort.h"
 #include "../util/log_stream.h"
 #include "reference.h"
+#include "../util/string/string.h"
+#include "../util/string/tokenizer.h"
 
-using std::cout;
-using std::endl;
-using std::set;
+using namespace std;
 
 Taxonomy taxonomy;
 
@@ -88,6 +89,26 @@ void Taxonomy::load_nodes()
 	f.close();
 }
 
+size_t Taxonomy::load_names() {
+	TextInputFile in(config.namesdmp);
+	string name, type;
+	long id;
+	size_t n = 0;
+	while (in.getline(), !in.eof()) {
+		if (in.line.empty())
+			continue;
+		Util::String::Tokenizer(in.line, "\t|\t") >> id >> name >> Util::String::Skip() >> type;
+		rstrip(type, "\t|");
+		if (type == "scientific name") {
+			name_.resize(id + 1);
+			name_[id] = name;
+			++n;
+		}
+	}
+	in.close();
+	return n;
+}
+
 void Taxonomy::init()
 {
 	task_timer timer;
@@ -95,14 +116,19 @@ void Taxonomy::init()
 		timer.go("Loading taxonomy");
 		load();
 		timer.finish();
-		log_stream << "Accession mappings = " << accession2taxid_.size() << endl;
+		message_stream << "Accession mappings = " << accession2taxid_.size() << endl;
 	}
-
 	if (!config.nodesdmp.empty()) {
 		timer.go("Loading taxonomy nodes");
 		load_nodes();
 		timer.finish();
 	}
+	if (!config.namesdmp.empty()) {
+		timer.go("Loading taxonomy names");
+		size_t n = load_names();
+		timer.finish();
+		message_stream << "Loaded taxonomy names for " << n << " taxon ids." << endl;
+	}
 }
 
 vector<string> Taxonomy::Accession::from_title(const char *title)
