@@ -36,33 +36,24 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../search/search.h"
 #include "workflow.h"
 #include "../util/io/consumer.h"
+#include "../util/parallel/thread_pool.h"
+#include "../util/system/system.h"
 
 using namespace std;
 
 namespace Workflow { namespace Search {
 
-struct Search_context
-{
-	Search_context(unsigned sid, const sorted_list &ref_idx, const sorted_list &query_idx) :
-		sid(sid),
-		ref_idx(ref_idx),
-		query_idx(query_idx)
-	{ }
-	void operator()(unsigned thread_id, unsigned seedp) const
-	{
-		Statistics stat;
-		align_partition(seedp,
-			stat,
-			sid,
-			ref_idx.get_partition_cbegin(seedp),
-			query_idx.get_partition_cbegin(seedp),
-			thread_id);
-		statistics += stat;
-	}
-	const unsigned sid;
-	const sorted_list &ref_idx;
-	const sorted_list &query_idx;
-};
+void search_worker(size_t p, size_t thread_id, unsigned sid, const sorted_list *ref_idx, const sorted_list *query_idx) {
+	Statistics stat;
+	align_partition((unsigned)p,
+		stat,
+		sid,
+		ref_idx->get_partition_cbegin(p),
+		query_idx->get_partition_cbegin(p),
+		thread_id);
+	statistics += stat;
+}
+
 
 void process_shape(unsigned sid,
 	unsigned query_chunk,
@@ -118,10 +109,9 @@ void process_shape(unsigned sid,
 			timer.go("Building seed filter");
 			frequent_seeds.build(sid, range, *ref_idx, query_idx);
 		}
-
+		
 		timer.go("Searching alignments");
-		Search_context context(sid, *ref_idx, query_idx);
-		launch_scheduled_thread_pool(context, Const::seedp, config.threads_);
+		Util::Parallel::scheduled_thread_pool_auto(config.threads_, Const::seedp, search_worker, sid, ref_idx, &query_idx);
 
 		delete ref_idx;
 	}
@@ -138,6 +128,7 @@ void run_ref_chunk(DatabaseFile &db_file,
 	const Metadata &metadata,
 	const vector<unsigned> &block_to_database_id)
 {
+	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
 	task_timer timer("Building reference histograms");
 	if(config.algo==Config::query_indexed)
 		ref_hst = Partitioned_histogram(*ref_seqs::data_, false, query_seeds);
@@ -258,6 +249,8 @@ void run_query_chunk(DatabaseFile &db_file,
 	delete query_seeds;
 	query_seeds = 0;
 
+	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
+
 	if (blocked_processing) {
 		timer.go("Joining output blocks");
 		join_blocks(current_ref_block, master_out, tmp_file, params, metadata, db_file);
@@ -372,6 +365,7 @@ void master_thread(DatabaseFile *db_file, Timer &total_timer, Metadata &metadata
 	metadata.free();
 
 	timer.finish();
+	log_stream << "Current RSS: " << getCurrentRSS() << ", Peak RSS: " << getPeakRSS() << endl;
 	message_stream << "Total time = " << total_timer.getElapsedTimeInSec() << "s" << endl;
 	statistics.print();
 }
@@ -398,7 +392,7 @@ void run(const Options &options)
 	DatabaseFile *db_file = options.db ? options.db : DatabaseFile::auto_create_from_fasta();
 	timer.finish();
 
-	init_output(db_file->has_taxon_id_lists(), db_file->has_taxon_nodes());
+	init_output(db_file->has_taxon_id_lists(), db_file->has_taxon_nodes(), db_file->has_taxon_scientific_names());
 
 	verbose_stream << "Reference = " << config.database << endl;
 	verbose_stream << "Sequences = " << db_file->ref_header.sequences << endl;
@@ -428,6 +422,13 @@ void run(const Options &options)
 		}
 		timer.finish();
 	}
+	if (output_format->needs_taxon_scientific_names) {
+		timer.go("Loading taxonomy names");
+		metadata.taxonomy_scientific_names = new vector<string>;
+		db_file->seek(db_file->header2.taxon_names_offset);
+		*db_file >> *metadata.taxonomy_scientific_names;
+		timer.finish();
+	}
 
 	master_thread(db_file, timer2, metadata, options);
 }
