@@ -19,9 +19,12 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <iostream>
 #include "../basic/config.h"
 #include "tools.h"
-#include "../extra/compare.h"
 #include "../data/reference.h"
 #include "workflow.h"
+#ifdef EXTRA
+#include "../extra/compare.h"
+#include "../extra/match_file.h"
+#endif
 
 using std::cout;
 using std::cerr;
@@ -43,6 +46,8 @@ void seed_stat();
 void pairwise();
 void protein_snps();
 void translate();
+void filter_blasttab();
+void show_cbs();
 
 int main(int ac, const char* av[])
 {
@@ -72,30 +77,12 @@ int main(int ac, const char* av[])
 		case Config::random_seqs:
 			random_seqs();
 			break;
-		case Config::compare:
-			compare();
-			break;
 		case Config::sort:
 			sort_file();
 			break;
-		case Config::roc:
-			roc();
-			break;
 		case Config::db_stat:
 			db_stat();
 			break;
-		case Config::model_sim:
-			model_sim();
-			break;
-		case Config::match_file_stat:
-			match_file_stat();
-			break;
-		case Config::model_seqs:
-			model_seqs();
-			break;
-		case Config::opt:
-			opt();
-			break;
 		case Config::mask:
 			run_masker();
 			break;
@@ -108,9 +95,6 @@ int main(int ac, const char* av[])
 		case Config::test_io:
 			test_io();
 			break;
-		case Config::db_annot_stats:
-			db_annot_stats();
-			break;
 		case Config::read_sim:
 			read_sim();
 			break;
@@ -129,7 +113,22 @@ int main(int ac, const char* av[])
 		case Config::translate:
 			translate();
 			break;
+		case Config::filter_blasttab:
+			filter_blasttab();
+			break;
+		case Config::show_cbs:
+			show_cbs();
+			break;
 #ifdef EXTRA
+		case Config::compare:
+			compare();
+			break;
+		case Config::model_sim:
+			model_sim();
+			break;
+		case Config::roc:
+			roc();
+			break;
 		case Config::test_extra:
 			test_main();
 			break;
@@ -139,6 +138,18 @@ int main(int ac, const char* av[])
 		case Config::seed_stat:
 			seed_stat();
 			break;
+		case Config::model_seqs:
+			model_seqs();
+			break;
+		case Config::opt:
+			opt();
+			break;
+		case Config::db_annot_stats:
+			db_annot_stats();
+			break;
+		case Config::match_file_stat:
+			match_file_stat();
+			break;
 #endif
 		default:
 			return 1;
