@@ -30,10 +30,8 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "../data/queries.h"
 #include "../data/load_seqs.h"
 #include "../data/reference.h"
-#include "../extra/match_file.h"
 #include "../basic/masking.h"
 #include "../dp/dp.h"
-#include "../util/tinythread.h"
 #include "../basic/packed_transcript.h"
 
 using namespace std;
@@ -112,14 +110,6 @@ void db_stat()
 
 }
 
-void match_file_stat()
-{
-	match_file file(config.match_file1.c_str());
-	blast_match match;
-	while (file.get(match, blast_format()));
-	file.get_subst();
-}
-
 void run_masker()
 {
 	TextInputFile f(config.query_file);
@@ -223,7 +213,7 @@ void info()
 	cout << endl;
 }
 
-void pairwise_worker(TextInputFile *in, tthread::mutex *input_lock, tthread::mutex *output_lock) {
+void pairwise_worker(TextInputFile *in, std::mutex *input_lock, std::mutex *output_lock) {
 	FASTA_format format;
 	vector<char> id_r, id_q, ref, query;
 
@@ -261,14 +251,15 @@ void pairwise()
 {
 	input_value_traits = nucleotide_traits;
 	value_traits = nucleotide_traits;
-	score_matrix = Score_matrix("DNA", 5, 2, 0);
+	score_matrix = Score_matrix("DNA", 5, 2, 0, 1);
 
 	TextInputFile in(config.query_file);
-	tthread::mutex input_lock, output_lock;
-	Thread_pool threads;
+	std::mutex input_lock, output_lock;
+	vector<thread> threads;
 	for (unsigned i = 0; i < config.threads_; ++i)
-		threads.push_back(launch_thread(pairwise_worker, &in, &input_lock, &output_lock));
-	threads.join_all();
+		threads.emplace_back(pairwise_worker, &in, &input_lock, &output_lock);
+	for (auto &t : threads)
+		t.join();
 }
 
 void fasta_skip_to(vector<char> &id, vector<char> &seq, string &blast_id, TextInputFile &f)
@@ -348,7 +339,7 @@ void protein_snps()
 		locus = stoi(t[i + 1]);
 		called_base = t[i + 3][0];
 
-		if (gene != current_gene) {
+		if (gene != current_gene || (config.use_dataset_field && t[0] != dataset)) {
 			call_protein_snps(current_gene, ref_genes[current_gene], snps, dataset);
 			snps.clear();
 			snps.insert(snps.begin(), ref_genes[gene].size(), vector<char>());
@@ -372,4 +363,17 @@ void translate() {
 		cout << sequence(proteins[0]) << endl;
 	}
 	in.close();
+}
+
+void show_cbs() {
+	score_matrix = Score_matrix("BLOSUM62", config.gap_open, config.gap_extend, config.frame_shift, 1);
+	init_cbs();
+	TextInputFile in(config.query_file);
+	vector<char> id, seq;
+	while (FASTA_format().get_seq(id, seq, in)) {
+		Bias_correction bc{ sequence(seq) };
+		for (size_t i = 0; i < seq.size(); ++i)
+			cout << value_traits.alphabet[(long)seq[i]] << '\t' << bc[i] << endl;
+	}
+	in.close();
 }
\ No newline at end of file
