@@ -3,16 +3,16 @@ DIAMOND protein aligner
 Copyright (C) 2013-2017 Benjamin Buchfink <buchfink@gmail.com>
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU Affero General Public License as
-published by the Free Software Foundation, either version 3 of the
-License, or (at your option) any later version.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU Affero General Public License for more details.
+GNU General Public License for more details.
 
-You should have received a copy of the GNU Affero General Public License
+You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ****/
 
@@ -23,12 +23,14 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "hit_filter.h"
 #include "../data/reference.h"
 #include "collision.h"
+#include "../dp/dp_matrix.h"
+
+template<typename _score> thread_local vector<score_vector<_score>> DP_matrix<_score>::scores_;
+template<typename _score> thread_local vector<score_vector<_score>> DP_matrix<_score>::hgap_;
 
 #ifdef __SSE2__
-TLS_PTR vector<sequence>* hit_filter::subjects_ptr;
-#endif
 
-#ifdef __SSE2__
+thread_local vector<sequence> hit_filter::subjects_;
 
 void search_query_offset(Loc q,
 	const sorted_list::const_iterator &s,
