@@ -21,6 +21,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #include <algorithm>
 #include <stddef.h>
+#include <thread>
 #include "thread.h"
 
 template<typename _it>
@@ -36,8 +37,8 @@ void merge_sort(_it begin, _it end, unsigned n_threads, unsigned level = 0)
 	}
 
 	_it mid = begin + diff/2;
-	thread *left = launch_thread(merge_sort<_it>, begin, mid, n_threads, level+1);
-	thread *right = launch_thread(merge_sort<_it>, mid, end, n_threads, level+1);
+	std::thread *left = new std::thread(merge_sort<_it>, begin, mid, n_threads, level+1);
+	std::thread *right = new std::thread(merge_sort<_it>, mid, end, n_threads, level+1);
 	left->join();
 	right->join();
 	delete left;
