@@ -104,11 +104,12 @@ inline _t round_up(_t x, _t m)
 inline vector<string> tokenize(const char *str, const char *delimiters)
 {
 	vector<string> out;
+	string token;
 	while(*str != 0) {
 		while(*str != 0 && strchr(delimiters, *str))
 			++str;
-		string token;
-		while(*str != 0 && strchr(delimiters, *str) == 0)
+		token.clear();
+		while(*str != 0 && strchr(delimiters, *str) == nullptr)
 			token += *(str++);
 		if(token.length() > 0)
 			out.push_back(token);
@@ -526,6 +527,24 @@ inline set<unsigned> parse_csv(const string &s)
 	return r;
 }
 
-std::string join(char c, const std::vector<std::string> &v);
+std::string join(const char *c, const std::vector<std::string> &v);
+
+template<typename _t, typename _f>
+auto apply(const std::vector<_t> &v, _f f) -> std::vector<typename std::result_of<_f(_t)>::type> {
+	std::vector<typename std::result_of<_f(_t)>::type> r;
+	r.reserve(v.size());
+	for (const auto &i : v)
+		r.push_back(f(i));
+	return r;
+}
+
+template<typename _t1, typename _t2>
+std::vector<std::pair<_t1, _t2>> combine(const std::vector<_t1> &v1, const std::vector<_t2> &v2) {
+	std::vector<std::pair<_t1, _t2>> r;
+	r.reserve(v1.size());
+	for (size_t i = 0; i < v1.size(); ++i)
+		r.emplace_back(v1[i], v2[i]);
+	return r;
+}
 
 #endif /* UTIL_H_ */
